summaryrefslogtreecommitdiff
path: root/test/offer_tests/offer_test_service.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'test/offer_tests/offer_test_service.cpp')
-rw-r--r--test/offer_tests/offer_test_service.cpp12
1 files changed, 7 insertions, 5 deletions
diff --git a/test/offer_tests/offer_test_service.cpp b/test/offer_tests/offer_test_service.cpp
index 13c193f..c56d005 100644
--- a/test/offer_tests/offer_test_service.cpp
+++ b/test/offer_tests/offer_test_service.cpp
@@ -16,7 +16,7 @@
#include <gtest/gtest.h>
#include <vsomeip/vsomeip.hpp>
-#include "../../implementation/logging/include/logger.hpp"
+#include <vsomeip/internal/logger.hpp>
#include "offer_test_globals.hpp"
@@ -26,11 +26,11 @@ class offer_test_service {
public:
offer_test_service(struct offer_test::service_info _service_info) :
service_info_(_service_info),
// service with number 1 uses "vsomeipd" as application name
// this way the same json file can be reused for all local tests
// including the ones with vsomeipd
app_(vsomeip::runtime::get()->create_application(
- (service_number == "1") ? "vsomeipd" :
+ (service_number == "1") ? "routingmanagerd" :
"offer_test_service" + service_number)),
counter_(0),
wait_until_registered_(true),
@@ -48,7 +48,9 @@ public:
std::set<vsomeip::eventgroup_t> its_eventgroups;
its_eventgroups.insert(service_info_.eventgroup_id);
app_->offer_event(service_info_.service_id, service_info_.instance_id,
- service_info_.event_id, its_eventgroups, false);
+ service_info_.event_id, its_eventgroups,
+ vsomeip::event_type_e::ET_EVENT, std::chrono::milliseconds::zero(),
+ false, true, nullptr, vsomeip::reliability_type_e::RT_UNKNOWN);
inc_counter_and_notify();
@@ -26,11 +26,11 @@ class offer_test_service {
offer_test_service(struct offer_test::service_info _service_info) :
service_info_(_service_info),
- // service with number 1 uses "vsomeipd" as application name
+ // service with number 1 uses "routingmanagerd" as application name
// this way the same json file can be reused for all local tests
@@ -26,11 +26,11 @@ class offer_test_service {
// this way the same json file can be reused for all local tests
- // including the ones with vsomeipd
+ // including the ones with routingmanagerd
app_(vsomeip::runtime::get()->create_application(